@@ -1,17 +1,15 @@
 #!/usr/bin/env python3
-# type: ignore [misc]
 
 """
 radiocc CLI.
 """
 
-
 from typing import Any
 
 import click
 from pudb import set_trace as bp  # noqa: F401
 
-from radiocc import NAME, VERSION, config, core
+import radiocc
 
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 
@@ -19,7 +17,7 @@ CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 def version(ctx: Any, param: Any, value: Any) -> None:
     if not value or ctx.resilient_parsing:
         return
-    click.echo(VERSION)
+    click.echo(radiocc.__version__)
     ctx.exit()
 
 
@@ -39,14 +37,25 @@ def version(ctx: Any, param: Any, value: Any) -> None:
     is_flag=True,
     help="Generate a config file `config.yaml` in the current directory.",
 )
-def cli(ctx: click.Context, generate_config: bool) -> None:
-    """Radio occultations."""
+@click.option(
+    "--download-data",
+    is_flag=True,
+    help="Download input data",
+)
+def cli(ctx: click.Context, generate_config: bool, download_data: bool) -> None:
+    """Radio occultations command-line entry point."""
     # Share default command options.
     ctx.ensure_object(dict)
     # ctx.obj["var"] = var
 
     if generate_config:
-        config.generate_config()
+        radiocc.config.Cfg().generate_config()
+        ctx.exit()
+
+    radiocc.cfg.load_config_file()
+
+    if download_data:
+        radiocc.download_data.proceed()
         ctx.exit()
 
     if ctx.invoked_subcommand is None:
@@ -64,14 +73,14 @@ def run(
     gui: bool,
 ) -> None:
     """Run radiocc."""
-    if not gui:
-        core.run()
-    else:
-        ctx.exit("the graphical interface is not implemented yet.")
+    if gui:
+        radiocc.cfg.graphical_interface = True
+
+    radiocc.core.run()
 
 
 def main() -> None:
-    cli(prog_name=NAME)
+    cli(prog_name="radiocc")
 
 
 if __name__ == "__main__":
