@@ -7,6 +7,7 @@ Export the graphs and text output.
 from typing import Optional  # noqa
 
 import numpy
+from nptyping import NDArray
 from pudb import set_trace as bp  # noqa
 
 from radiocc.model import Export, L2Data, Scenario
@@ -19,8 +20,9 @@ def run(SCENARIO: Scenario, L2DATA: L2Data, OUT: Export) -> None:
     COUNT = len(list(OUT.DATA_PATH.glob(PATH_FILTER)))
     PATH_OUT = OUT.DATA_PATH / (PATH_FILTER % (COUNT + 1))
 
-    output = numpy.stack(
+    output: NDArray = numpy.stack(
         (
+            OUT.ET,
             OUT.DOPPLER,
             OUT.DOPPLER_DEBIAS,
             OUT.DOPPLER_BIAS_FIT,
@@ -30,6 +32,7 @@ def run(SCENARIO: Scenario, L2DATA: L2Data, OUT: Export) -> None:
             OUT.ERROR,
             OUT.ERROR_REFRAC,
             OUT.ERROR_ELEC,
+            OUT.BEND_RADIUS,
         ),
         axis=1,
     )
@@ -37,6 +40,20 @@ def run(SCENARIO: Scenario, L2DATA: L2Data, OUT: Export) -> None:
     if OUT.TEC is not None:
         output = numpy.concatenate((output, OUT.TEC[:, None]), axis=1)
 
+    if OUT.PT is not None:
+        output = numpy.concatenate(
+            (
+                output,
+                OUT.PT.P_low[:, None],
+                OUT.PT.P_med[:, None],
+                OUT.PT.P_upp[:, None],
+                OUT.PT.T_low[:, None],
+                OUT.PT.T_med[:, None],
+                OUT.PT.T_upp[:, None],
+            ),
+            axis=1,
+        )
+
     numpy.savetxt(
         PATH_OUT,
         output,
