@@ -8,10 +8,12 @@ from enum import auto
 from pathlib import Path
 from typing import List, Optional, Union
 
+from dotmap import DotMap
 from nptyping import NDArray
 from pudb import set_trace as bp  # noqa
 
-from radiocc.util import AutoEnum, GetAttributes, raise_error
+import radiocc
+from radiocc.utils import AutoEnum, GetAttributes, raise_error
 
 
 class Folders(AutoEnum):
@@ -59,6 +61,21 @@ class ProcessType(AutoEnum):
     MAVEN = auto()
 
 
+class KernelVersion(AutoEnum):
+    """Possible ways to select kernel version in non-interactive mode."""
+
+    FIRST = auto()
+    LATEST = auto()
+
+
+class RadioDataType(AutoEnum):
+    """A radio data"""
+
+    EGRESS = auto()
+    INGRESS = auto()
+    BOTH = auto()
+
+
 class LV2Loops(AutoEnum):
     """Possible type of folder in LVL2 data loop."""
 
@@ -128,6 +145,10 @@ class Scenario:
     def results(self, RESULTS: Path) -> Path:
         return RESULTS / self.TO_PROCESS.name
 
+    def read_descriptor(self) -> DotMap:
+        DESCRIPTOR_PATH = self.TO_PROCESS / radiocc.DESCRIPTOR_FILENAME
+        return radiocc.utils.read_yaml(DESCRIPTOR_PATH)
+
 
 class MexData:
     """Input data from MEX."""
@@ -164,19 +185,36 @@ class L2Data:
     DATA: Union[MexData, MavenData]
 
 
+class PressTemp:
+    """
+    Structure representation of the data to be exported for pressure and
+    temperature.
+    """
+
+    P_low: NDArray[float]
+    P_med: NDArray[float]
+    P_upp: NDArray[float]
+    T_low: NDArray[float]
+    T_med: NDArray[float]
+    T_upp: NDArray[float]
+
+
 class Export:
     """Structure representation of the data to be exported for a scenario."""
 
     DATA_PATH: Path
     PLOT_PATH: Path
     EPHE_PATH: Path
+    ET: NDArray[float]
     DOPPLER: NDArray[float]
     DOPPLER_DEBIAS: NDArray[float]
     DOPPLER_BIAS_FIT: NDArray[float]
     DISTANCE: NDArray[float]
     REFRACTIVITY: NDArray[float]
     NE: NDArray[float]
-    TEC: Optional[NDArray[float]]
+    TEC: Optional[NDArray[float]] = None
     ERROR: NDArray[float]
     ERROR_REFRAC: NDArray[float]
     ERROR_ELEC: NDArray[float]
+    PT: Optional[PressTemp] = None
+    BEND_RADIUS: NDArray[float]
