@@ -13,10 +13,12 @@ import numpy
 import spiceypy as spice
 from colored import attr, fg
 from nptyping import NDArray
-from pudb import set_trace as bp  # noqa
+from pudb import set_trace as bp  # noqa:F401
+from scipy.ndimage.filters import uniform_filter1d  # noqa:F401
+from scipy.signal import butter, filtfilt  # noqa:F401
 
 import radiocc
-from radiocc import constants, util
+from radiocc import constants
 from radiocc.model import (
     L2Data,
     LV2Loops,
@@ -27,6 +29,8 @@ from radiocc.model import (
     Scenario,
 )
 
+# from radiocc.utils import DOTMAP_NONE
+
 SPICE_FOLDERS = dict(
     SPK=("*.bsp",),
     SCLK=("*.tsc",),
@@ -36,8 +40,8 @@ SPICE_FOLDERS = dict(
     FK=("*.tf",),
     CK=("*.bc",),
 )
-SPICE_RPATH = dict(MEX="EXTRAS/ANCILLARY/SPICE", MAVEN="SPICE")
-LV2_RPATH = "DATA/LEVEL02"
+SPICE_RPATH_MEX = Path("EXTRAS/ANCILLARY/SPICE")
+LV2_RPATH = Path("DATA/LEVEL02")
 DATA_RPATH_MAVEN = "DATA"
 METADATA_SUFFIX_MEX = ".LBL"
 STATION_RPATH = "STATION.txt"
@@ -77,22 +81,48 @@ def prepare_directories(scenario: Scenario) -> None:
     (RESULTS / ResultsFolders.EPHEMERIDS.name).mkdir(parents=True, exist_ok=True)
 
 
-def load_spice_kernels(PROCESS_PATH: Path, FOLDER_TYPE: ProcessType) -> None:
+def load_spice_kernels(SCENARIO: Scenario, FOLDER_TYPE: ProcessType) -> None:
     """Load SPICE kernels."""
-    SPICE_PATH = PROCESS_PATH / SPICE_RPATH[FOLDER_TYPE.name]
-
     # Ensure no conflict with previously loaded kernels.
     spice.kclear()
 
-    # Iterate SPICE bundle folders.
-    for FOLDER, FILTERS in SPICE_FOLDERS.items():
-        for FILTER in FILTERS:
-            FILES = list((SPICE_PATH / FOLDER).glob(FILTER))
-            FILES.extend(list((SPICE_PATH / FOLDER).glob(FILTER.upper())))
+    # MEX has SPICE kernels inside the same folder, which is bad because most kernels
+    # are duplicates: space and download are not optimized. Plus, they don't have meta-
+    # kernels so you need to load every piece of them.
+    if FOLDER_TYPE == ProcessType.MEX:
+        SPICE_PATH = SCENARIO.TO_PROCESS / SPICE_RPATH_MEX
 
-            # Iterate files in each folder.
-            for FILE in FILES:
-                spice.furnsh(str(FILE))
+        # Iterate SPICE bundle folders.
+        for FOLDER, FILTERS in SPICE_FOLDERS.items():
+            for FILTER in FILTERS:
+                FILES = list((SPICE_PATH / FOLDER).glob(FILTER))
+                FILES.extend(list((SPICE_PATH / FOLDER).glob(FILTER.upper())))
+
+                # Iterate files in each folder.
+                for FILE in FILES:
+                    spice.furnsh(str(FILE))
+
+    # MAVEN data are downloaded in such a way that you never download data twice, so
+    # there is a general kernel folder outside the scenario to be processed. Plus, we
+    # use meta-kernels because it's damn simpler!
+    else:
+        # FIXME: uncomment when SPICE maven is fixed
+        # DESCR = SCENARIO.read_descriptor()
+        # if DESCR.meta_kernel in DOTMAP_NONE:
+        #     raise NotImplementedError
+        # SPICE_PATH = radiocc.cfg.to_process / radiocc.SPICE_MAVEN_DIRECTORY
+        # META_KERNEL = SPICE_PATH / DESCR.meta_kernel
+        # spice.furnsh(str(META_KERNEL))
+
+        # This below is temporary solution
+        SPICE_PATH = SCENARIO.TO_PROCESS.parent / "spice-maven"
+        for FOLDER, FILTERS in SPICE_FOLDERS.items():  # Iterate SPICE bundle folders.
+            for FILTER in FILTERS:
+                FILES = list((SPICE_PATH / FOLDER).glob(FILTER))
+                FILES.extend(list((SPICE_PATH / FOLDER).glob(FILTER.upper())))
+                # Iterate files in each folder.
+                for FILE in FILES:
+                    spice.furnsh(str(FILE))
 
     print("      SPICE kernels loaded.")
 
@@ -102,9 +132,9 @@ def detect_folder_type(PROCESS_PATH: Path) -> Optional[ProcessType]:
     # Detect if MEX or MAVEN format.
     folder_type: Optional[ProcessType] = None
     print(f"      {PROCESS_PATH.name}")
-    if PROCESS_PATH.name[:3] == "MEX" and PROCESS_PATH.name[-4:] == "V1.0":
+    if PROCESS_PATH.name[:3] == "MEX":  # and PROCESS_PATH.name[-4:] == "V1.0":
         folder_type = ProcessType.MEX
-    elif PROCESS_PATH.name[:3] == "mvn":
+    elif PROCESS_PATH.name[:5] == "maven":
         folder_type = ProcessType.MAVEN
 
     # Exit if neither MEX nor MAVEN.
@@ -117,7 +147,7 @@ def detect_folder_type(PROCESS_PATH: Path) -> Optional[ProcessType]:
             f"{s}  + folder name should start with `MEX`.\n"
             "\n"
             f"{s}MAVEN conventions are:\n"
-            f"{s}  + folder name should start with `mvn`.\n"
+            f"{s}  + folder name should start with `maven`.\n"
         )
 
     return folder_type
@@ -128,7 +158,7 @@ def get_data_file(SCENARIO: Scenario, FOLDER_TYPE: ProcessType) -> Optional[Path
     if FOLDER_TYPE == ProcessType.MEX:
         # Get DATA LEVEL02
         LV2_PATH = SCENARIO.TO_PROCESS / LV2_RPATH
-        LV2_ITER = util.directories(LV2_PATH)
+        LV2_ITER = iter(sorted(radiocc.utils.directories(LV2_PATH, EXCLUDES=".*")))
         try:
             LV2_LOOP = next(LV2_ITER)
         except StopIteration:
@@ -137,7 +167,7 @@ def get_data_file(SCENARIO: Scenario, FOLDER_TYPE: ProcessType) -> Optional[Path
             return None
 
         # Check if IFMS or DSN.
-        LOOP_ITER = util.directories(LV2_LOOP)
+        LOOP_ITER = iter(sorted(radiocc.utils.directories(LV2_LOOP, EXCLUDES=".*")))
         LOOP_OPTION = next(LOOP_ITER)
         if LOOP_OPTION.name == LV2Loops.IFMS.name:
             DATA_FOLDER = LOOP_OPTION / "DP1"
@@ -162,8 +192,8 @@ def get_data_file(SCENARIO: Scenario, FOLDER_TYPE: ProcessType) -> Optional[Path
         DATA_FILTER = f"*_{DATA_FOLDER_FILTER}_*.TAB"
 
     elif FOLDER_TYPE == ProcessType.MAVEN:
-        DATA_FOLDER = SCENARIO.TO_PROCESS / DATA_RPATH_MAVEN
-        DATA_FILTER = "*.tab"
+        DATA_FOLDER = SCENARIO.TO_PROCESS
+        DATA_FILTER = "*_l2_*.csv"
 
     else:
         print(
@@ -172,7 +202,7 @@ def get_data_file(SCENARIO: Scenario, FOLDER_TYPE: ProcessType) -> Optional[Path
             f"{attr(0)}"
         )
 
-    DATA_FILES_ITER = iter(sorted(DATA_FOLDER.glob(DATA_FILTER), reverse=False))
+    DATA_FILES_ITER = iter(sorted(DATA_FOLDER.glob(DATA_FILTER), reverse=True))
 
     # Check that the data folder actually contains some files.
     try:
@@ -197,7 +227,7 @@ def get_metadata_file(
     if FOLDER_TYPE == ProcessType.MEX:
         METADATA_FILE = DATA_FILE.with_suffix(METADATA_SUFFIX_MEX)
     else:
-        METADATA_FILTER = "*.csv"
+        METADATA_FILTER = "*_l0_*.csv"
         METADATA_FILES_ITER = iter(
             sorted(DATA_FILE.parent.glob(METADATA_FILTER), reverse=False)
         )
@@ -249,8 +279,11 @@ def read_input_metadata(l2_data: L2Data) -> L2Data:
         # Get information in LBL file.
         information_in_LBL = dict(DSN_STATION_NUMBER=False, DISTANCE=False)
         for idx, LINE in enumerate(LBL_LINES):
-            if "DSN_STATION_NUMBER" in LINE:
-                DSN_STATION_NUMBER = int(float(LINE.split("=")[1]))
+            if (
+                "DSN_STATION_NUMBER" in LINE
+                and not information_in_LBL["DSN_STATION_NUMBER"]
+            ):
+                DSN_STATION_NUMBER = int(LINE.strip().split("=")[1].strip().strip('"'))
                 DSN_STATION_NAIF_CODE = START_STATIONS_NAIF_CODE + DSN_STATION_NUMBER
                 information_in_LBL["DSN_STATION_NUMBER"] = True
 
@@ -261,14 +294,7 @@ def read_input_metadata(l2_data: L2Data) -> L2Data:
                 if UNIT:
                     DISTANCE_UNIT = UNIT.group(1)
                 else:
-                    raise SystemExit(
-                        NotImplementedError(
-                            f"{fg('red')}"
-                            "Error: "
-                            "Cannot parse distance unit."
-                            f"{attr(0)}"
-                        )
-                    )
+                    raise NotImplementedError("Cannot parse distance unit.")
 
                 information_in_LBL["DISTANCE"] = True
 
@@ -278,8 +304,6 @@ def read_input_metadata(l2_data: L2Data) -> L2Data:
         l2_data.DISTANCE_UNIT = DISTANCE_UNIT
 
     elif l2_data.FOLDER_TYPE == ProcessType.MAVEN:
-        # FIXME
-        # mypy issue with numpy untyped call
         DATA_ARRAY = numpy.genfromtxt(
             l2_data.METADATA_FILE,
             dtype=None,
@@ -368,13 +392,19 @@ def read_L2_metadata(l2_data: L2Data, INFORMATION_PATH: Path) -> L2Data:
 
 def read_tab_data(l2_data: L2Data) -> L2Data:
     """read the tab file."""
-    # Read data from TAB file.
-    # FIXME
-    # mypy issue with numpy untyped call
-    DATA_ARRAY = numpy.genfromtxt(l2_data.DATA_FILE, dtype=None, encoding="utf-8")
-    DATA_NROWS = DATA_ARRAY.shape[0]
 
     if l2_data.FOLDER_TYPE == ProcessType.MEX:
+        # Read data from TAB file.
+        # FIXME
+        # mypy issue with numpy untyped call
+        print(l2_data.DATA_FILE)
+        DATA_ARRAY = numpy.genfromtxt(l2_data.DATA_FILE, dtype=None, encoding="utf-8")
+
+        if radiocc.cfg.quick_trace:
+            DATA_ARRAY = DATA_ARRAY[-1:]
+
+        DATA_NROWS = DATA_ARRAY.shape[0]
+
         # Initialize individual column arrays.
         et = numpy.zeros(DATA_NROWS)
         utc = [""] * DATA_NROWS
@@ -404,6 +434,9 @@ def read_tab_data(l2_data: L2Data) -> L2Data:
 
         distance *= UNITS[l2_data.DISTANCE_UNIT]
 
+        # TODO: check if this line is correct
+        constants.Threshold_Surface = distance[-1]
+
         SURFACES_CONDITIONS: NDArray[float] = distance <= constants.Threshold_Surface
         INTEGRAL_CONDITIONS: NDArray[float] = distance <= constants.Threshold_int
 
@@ -421,6 +454,15 @@ def read_tab_data(l2_data: L2Data) -> L2Data:
         l2_data.DATA = mex_data
 
     elif l2_data.FOLDER_TYPE == ProcessType.MAVEN:
+        DATA_ARRAY = numpy.genfromtxt(
+            l2_data.DATA_FILE,
+            dtype=None,
+            comments="#",
+            delimiter=",",
+            skip_header=1,
+        )
+        DATA_NROWS = DATA_ARRAY.shape[0]
+
         et = numpy.zeros(DATA_NROWS)
         # fsky = numpy.zeros(DATA_NROWS)
         doppler = numpy.zeros(DATA_NROWS)
@@ -432,8 +474,17 @@ def read_tab_data(l2_data: L2Data) -> L2Data:
             # fsky[idx] = LINE[DATA_COL_IDX_MVN["fsky"]]
             doppler[idx] = LINE[DATA_COL_IDX_MVN["fresid"]]
 
+            ssss_t = int((ERTSEC - int(ERTSEC)) * 10000)
             time_format = time.strftime("%H:%M:%S", time.gmtime(ERTSEC))
-            Utime = str(ERTYR) + "-" + str(ERTDOY) + "T" + str(time_format)
+            Utime = (
+                str(ERTYR)
+                + "-"
+                + str(ERTDOY)
+                + "T"
+                + str(time_format)
+                + "."
+                + str(ssss_t)
+            )
             et[idx] = spice.str2et(Utime)
 
         # Export data.
@@ -469,3 +520,97 @@ def read_L2_data(SCENARIO: Scenario, FOLDER_TYPE: ProcessType) -> Optional[L2Dat
     l2_data = read_tab_data(l2_data)
 
     return l2_data
+
+
+def butter_lowpass_filter(
+    data: NDArray, cutoff: float, fs: float, order: int
+) -> NDArray:
+    nyq = 0.5 * fs
+    normal_cutoff = cutoff / nyq
+    # Get the filter coefficients
+    b, a = butter(order, normal_cutoff, btype="low", analog=False)
+    y = filtfilt(b, a, data)
+    return y
+
+
+def filtering(L2_DATA: L2Data) -> None:
+    """Filter data."""
+    if not radiocc.cfg.filter:
+        return
+
+    # L2_DATA.DATA.DIFF_DOPPLER = numpy.convolve(
+    #   L2_DATA.DATA.DIFF_DOPPLER, numpy.ones(FILTERED_SIZE)/FILTERED_SIZE, mode='valid'
+    # )
+
+    # General filter parameters.
+    SKIP = 5
+
+    # Uniform filter parameters.
+    LENGTH_FILTER = 10  # noqa:F841
+
+    # Butter lowpass filter parameters.
+    CUTOFF = 2.0
+    FS = 10.0
+    ORDER = 2
+
+    # Apply average filter.
+    if L2_DATA.FOLDER_TYPE == ProcessType.MEX:
+        DATA_NAMES = ["DIFF_DOPPLER", "DOPPLER"]
+    else:
+        DATA_NAMES = [
+            "DOPPLER",
+        ]
+
+    for DATA_NAME in DATA_NAMES:
+        DATA = L2_DATA.DATA.__getattribute__(DATA_NAME)
+        NEW_DATA = butter_lowpass_filter(DATA, CUTOFF, FS, ORDER)
+        # NEW_DATA = uniform_filter1d(DATA, size=LENGTH_FILTER)
+        # NEW_DATA = radiocc.fft_filter.fft_filter(DATA)
+        # NEW_DATA = numpy.convolve(
+        #     DATA, numpy.ones(LENGTH_FILTER) / LENGTH_FILTER, mode="valid"
+        # )
+        L2_DATA.DATA.__setattr__(DATA_NAME, NEW_DATA)
+
+    # Skip end.
+    # for DATA_NAME in (
+    #     "DISTANCE",
+    #     "ERROR",
+    #     "ET",
+    #     "INTEGRAL_CONDITIONS",
+    #     "SURFACES_CONDITIONS",
+    #     "UTC",
+    # ):
+    #     DATA = L2_DATA.DATA.__getattribute__(DATA_NAME)
+    #     NEW_DATA = DATA[: -LENGTH_FILTER + 1 :]
+    #     L2_DATA.DATA.__setattr__(DATA_NAME, NEW_DATA)
+
+    # Skip data.
+    if L2_DATA.FOLDER_TYPE == ProcessType.MEX:
+        DATA_NAMES = [
+            "DIFF_DOPPLER",
+            "DOPPLER",
+            "DISTANCE",
+            "ERROR",
+            "ET",
+            "INTEGRAL_CONDITIONS",
+            "SURFACES_CONDITIONS",
+            "UTC",
+        ]
+    else:
+        DATA_NAMES = ["DOPPLER", "ET"]
+    for DATA_NAME in DATA_NAMES:
+        DATA = L2_DATA.DATA.__getattribute__(DATA_NAME)
+        NEW_DATA = DATA[::SKIP]
+        L2_DATA.DATA.__setattr__(DATA_NAME, NEW_DATA)
+
+
+def show_info(L2_DATA: L2Data) -> None:
+    """Show information about the input data."""
+    MEAN_DT = numpy.mean(L2_DATA.DATA.ET[1:] - L2_DATA.DATA.ET[:-1])
+    TOTAL_ELAPSED = L2_DATA.DATA.ET[-1] - L2_DATA.DATA.ET[0]
+    NUMBER_LINES = L2_DATA.DATA.ET.shape[0]
+
+    TAB = "      "
+    print(f"{TAB}Number of lines: {NUMBER_LINES}")
+    print(f"{TAB}Total elapsed time: {TOTAL_ELAPSED}s")
+    print(f"{TAB}Mean delta-time: {MEAN_DT}s")
